/*
 * This file belongs to the IntoJ project. See enclosed license file for
 * licensing issues.
 * 
 * For more information, please visit http://www.intoj.org/
 *  
 */
package org.intoJ.inferType3.internal.constraintModel.variables;

import org.eclipse.jdt.core.dom.IMethodBinding;
import org.eclipse.jdt.internal.corext.refactoring.typeconstraints.types.TType;
import org.eclipse.jdt.internal.corext.refactoring.typeconstraints2.ConstraintVariable2;

/**
 * A variable representing the declaring type of a method. 
 * <p>
 * This is only used for methods that can be moved to another type 
 * (otherwise an {@link ImmutableTypeVariableWithDescr} is used).
 * The binding key of the method will stored to match them later on with
 * the bindings from the hierarchy of the selection. 
 * <p> 
 * 
 * @author Hannes Kegel
 *
 */
public class DeclaringTypeVariable extends ConstraintVariable2 implements BindingKeyProvider {

    private String bindingKey;

    /**
     * The single constructor.
     * 
     * @param method the method invoked
     * @param type the current declaring type of the method
     */
    public DeclaringTypeVariable(IMethodBinding method, TType type) {
        super(type);
        bindingKey = method.getMethodDeclaration().getKey();
        
        //LogUtil.debugOut2(this, "creating declaring type " + bindingKey);
    }

    /**
     * Returns the binding key of the invoked method.
     * @return the binding key
     */
    public String getBindingKey() {
        return bindingKey;
    }

    /*
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        return bindingKey.hashCode();
    }

    /*
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object other) {
        if (this == other) {
            return true;
        }
        if (other.getClass() != DeclaringTypeVariable.class) {
            return false;
        }
        
        return getBindingKey().equals(((DeclaringTypeVariable) other).getBindingKey());
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.jdt.internal.corext.refactoring.typeconstraints2.ConstraintVariable2#toString()
     */
    @Override
    public String toString() {
        return getBindingKey().toString();
    }

}
