/*
 * This file belongs to the IntoJ project. See enclosed license file for
 * licensing issues.
 * 
 * For more information, please visit http://www.intoj.org/
 *  
 */
package org.intoJ.inferType3.internal.constraintModel.variables;

import org.eclipse.core.runtime.Assert;
import org.eclipse.jdt.core.ICompilationUnit;
import org.eclipse.jdt.core.dom.IMethodBinding;
import org.eclipse.jdt.internal.corext.refactoring.typeconstraints.types.TType;
import org.eclipse.jdt.internal.corext.refactoring.typeconstraints2.ConstraintVariable2;
import org.eclipse.jdt.internal.corext.refactoring.typeconstraints2.ISourceConstraintVariable;
import org.eclipse.jdt.internal.corext.refactoring.typeconstraints2.ParameterTypeVariable2;

/**
 * An IndependentParameterTypeVariable stands for the parameter of a method, but is independent
 * from other invocations or from the declaration. 
 * <p>
 * In constrast to {@link ParameterTypeVariable2} there is not only one distinct variable 
 * per parameter. This independent variable is needed to connect parameters to receiver elements when 
 * the parameter contains type variables or wildcards, but avoids connecting all invocations 
 * independent of the receiver. 
 * </p> 
 * @author Hannes Kegel
 *
 */
public class IndependentParameterTypeVariable extends ConstraintVariable2 implements ISourceConstraintVariable {
    private final int fParameterIndex;
    private final String fKey;
    private ICompilationUnit fCompilationUnit;
    
    /**
     * The single constructor.
     * 
     * @param type the current type
     * @param index the index of the parameter
     * @param binding the method invoked
     */
    public IndependentParameterTypeVariable(TType type, int index, IMethodBinding binding) {
        super(type);
        Assert.isNotNull(binding);
        Assert.isTrue(0 <= index);
        fParameterIndex= index;
        fKey= binding.getKey();
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.jdt.internal.corext.refactoring.typeconstraints2.ISourceConstraintVariable#setCompilationUnit(org.eclipse.jdt.core.ICompilationUnit)
     */
    public void setCompilationUnit(ICompilationUnit cu) {
        fCompilationUnit= cu;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.jdt.internal.corext.refactoring.typeconstraints2.ISourceConstraintVariable#getCompilationUnit()
     */
    public ICompilationUnit getCompilationUnit() {
        return fCompilationUnit;
    }

    /* (non-Javadoc)
     * @see org.eclipse.jdt.internal.corext.refactoring.typeconstraints2.ConstraintVariable2#toString()
     */
    @Override
    public String toString() {
        String toString= (String) getData(TO_STRING);
        return toString == null ? "[IndependentParameter(" + fParameterIndex + "," + fKey + ")]" : toString; 
    }

}
