package org.intoJ.inferType3.internal.ui;

import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;
import org.intoJ.inferType3.InferTypePlugin;

/**
 * The preference page for Infer Type. Contains two options: 
 * <ul>
 * <li>if a new interfaces will be created even if the original type only 
 * contains additional private or package-private members.</li>
 * <li>if the graph export panel will be shown in the wizard.
 * </li>
 * </ul>
 * 
 * @author Hannes Kegel
 *
 */
public class ITPreferencePage extends PreferencePage
                            implements IWorkbenchPreferencePage
{
    
    private Button chkConsiderPrivate;
    private Button chkShowExport;
    
    /* (non-Javadoc)
     * @see org.eclipse.jface.preference.PreferencePage#createContents(org.eclipse.swt.widgets.Composite)
     */
    protected Control createContents(Composite parent) {

    	Composite pageComponent = new Composite(parent, SWT.NULL);
        RowLayout rowLayout = new RowLayout(SWT.VERTICAL);
        rowLayout.spacing = 5;
    	pageComponent.setLayout(rowLayout);
    	
        chkConsiderPrivate = new Button(pageComponent, SWT.CHECK);
        chkConsiderPrivate.setText("Don't consider types with (package) private members minimal");

        chkShowExport = new Button(pageComponent, SWT.CHECK);
        chkShowExport.setText("Show graph export panel in the wizard");

        ApplySelectionListener applySelectionListener = new ApplySelectionListener();
        chkConsiderPrivate.addSelectionListener(applySelectionListener);
        chkShowExport.addSelectionListener(applySelectionListener);

        init(null);
		return pageComponent;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
     */
    public void init(IWorkbench workbench) {
        if (chkConsiderPrivate == null) {
            return;
        }
        IPreferenceStore store = getPreferenceStore();
        chkConsiderPrivate.setSelection(store.getBoolean(InferTypePlugin.PREFNAME_CONSIDER_PRIVATE));
        chkShowExport.setSelection(store.getBoolean(InferTypePlugin.PREFNAME_SHOW_EXPORT));
    }

	/* (non-Javadoc)
	 * @see org.eclipse.jface.preference.PreferencePage#doGetPreferenceStore()
	 */
	protected IPreferenceStore doGetPreferenceStore() {
        return InferTypePlugin.getDefault().getPreferenceStore();
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.preference.PreferencePage#performOk()
     */
    public boolean performOk() {
        storeValues();
        InferTypePlugin.getDefault().savePluginPreferences();
        return true;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.jface.preference.PreferencePage#performDefaults()
     */
    protected void performDefaults() {
        if (chkConsiderPrivate != null) {
            chkConsiderPrivate.setSelection(false);
            chkShowExport.setSelection(false);
        }
        super.performDefaults();
    }
    
    private void storeValues() {
        if (chkConsiderPrivate == null) {
            return;
        }
        
        IPreferenceStore store = getPreferenceStore();
        store.setValue(InferTypePlugin.PREFNAME_CONSIDER_PRIVATE, chkConsiderPrivate.getSelection());
        store.setValue(InferTypePlugin.PREFNAME_SHOW_EXPORT, chkShowExport.getSelection());
    }
    
    private class ApplySelectionListener extends SelectionAdapter {
        /* (non-Javadoc)
         * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
         */
        public void widgetSelected(SelectionEvent e) {
            updateApplyButton();
        }        
    }
    
    
}
