/*
 * This file belongs to the IntoJ project. See enclosed license file for
 * licensing issues.
 * 
 * For more information, please visit http://www.intoj.org/
 *  
 */
package org.intoJ.inferType3.internal.util;

import java.util.LinkedHashMap;
import java.util.Map;

/**
 * A custom hash map implementation with a cap that removes
 * the eldest entry if necessary.
 * 
 * @author Hannes Kegel
 *
 * @param <K> the key type
 * @param <V> the value type
 */
public class CacheMap<K, V> extends LinkedHashMap<K, V> {
    private int maxCache;

    private static final long serialVersionUID = 1L;

    /**
     * The single constructor.
     * 
     * @param maxCache the cap
     */
    public CacheMap(int maxCache) {
        super(maxCache, 0.75f, true);            
        this.maxCache = maxCache;
    }
    
    /* (non-Javadoc)
     * @see java.util.LinkedHashMap#removeEldestEntry(java.util.Map.Entry)
     */
    @Override
    protected final boolean removeEldestEntry(Map.Entry entry) {
        return size() > maxCache;
    }

}
